#!/bin/bash
export JAVA_HOME=/usr/java/default
export HADOOP_CLASSPATH=${JAVA_HOME}/lib/tools.jar

echo "Prepare output and input directories and files..."
hadoop fs -mkdir -p "hadoop-examples/wordcount" "hadoop-examples/wordcount/input"
hadoop fs -test -d "hadoop-examples/wordcount/output"
if [ "$?" == "0" ]; then
    hadoop fs -rm -r "hadoop-examples/wordcount/output"
fi
hadoop fs -put -f input/file* "hadoop-examples/wordcount/input"

echo "Compiling Wordcount Program..."
mkdir -p "/tmp/${USER}/hadoop-examples/wordcount/"
cp WordCountWithDebugOutput.java "/tmp/${USER}/hadoop-examples/wordcount/"
cd "/tmp/${USER}/hadoop-examples/wordcount/"
hadoop com.sun.tools.javac.Main WordCountWithDebugOutput.java
jar cf wordcount.jar WordCountWithDebugOutput*.class

echo "Running wordcount program..."
exec 5>&1
APPLICATION_ID=$(hadoop jar wordcount.jar WordCountWithDebugOutput "hadoop-examples/wordcount/input" "hadoop-examples/wordcount/output" 2>&1 | tee >(cat - >&5) | awk '!found && /INFO.*Yarn.*Submitted application/ {tmp=gensub(/^.*Submitted application (.*)$/,"\\1","g");print tmp; found=1}')
echo "================================================="
echo "Applicaton id: $APPLICATION_ID"
echo "=========== COLLECTED DEBUG OUTPUT FROM MAPPERS AND REDUCERS ============"
COUNT=0
(while [ -n "$APPLICATION_ID" ]; do
    COUNT=$((COUNT+1))
    yarn logs -applicationId "$APPLICATION_ID" 
    if [ "$?" == 0 -o "$COUNT" -gt 10 ]; then
	break
    fi
    echo "Logs not ready yet, waiting." >&2
    sleep 1
done) | grep -v "^[0-9-]\+ [0-9:,]\+ \(INFO\|WARN\)"    
echo "================= FINAL WORDCOUNT OUTPUT ================================"
hadoop fs -cat "hadoop-examples/wordcount/output"/*
echo "========================================================================="
